@@ -17,7 +17,7 @@ class FeatureGroupVersion(AbstractApiClass):
             featureGroupVersion (str): The unique identifier for this materialized version of feature group.
             featureGroupId (str): The unique identifier of the feature group this version belongs to.
             sql (str): The sql definition creating this feature group.
-            sourceTables (list of string): The source tables for this feature group.
+            sourceTables (list[str]): The source tables for this feature group.
             createdAt (str): The timestamp at which the feature group version was created.
             status (str): The current status of the feature group version.
             error (str): Relevant error if the status is FAILED.
@@ -25,12 +25,14 @@ class FeatureGroupVersion(AbstractApiClass):
             cpuSize (str): Cpu size specified for the python feature group.
             memory (int): Memory in GB specified for the python feature group.
             useOriginalCsvNames (bool): If true, the feature group will use the original column names in the source dataset.
+            pythonFunctionBindings (list): Config specifying variable names, types, and values to use when resolving a Python feature group.
+            annotationConfig (dict): The annotations config for the feature group.
             features (Feature): List of features.
             pointInTimeGroups (PointInTimeGroup): List of Point In Time Groups
             codeSource (CodeSource): If a python feature group, information on the source code
     """
 
-    def __init__(self, client, featureGroupVersion=None, featureGroupId=None, sql=None, sourceTables=None, createdAt=None, status=None, error=None, deployable=None, cpuSize=None, memory=None, useOriginalCsvNames=None, features={}, pointInTimeGroups={}, codeSource={}):
+    def __init__(self, client, featureGroupVersion=None, featureGroupId=None, sql=None, sourceTables=None, createdAt=None, status=None, error=None, deployable=None, cpuSize=None, memory=None, useOriginalCsvNames=None, pythonFunctionBindings=None, annotationConfig=None, features={}, pointInTimeGroups={}, codeSource={}):
         super().__init__(client, featureGroupVersion)
         self.feature_group_version = featureGroupVersion
         self.feature_group_id = featureGroupId
@@ -43,13 +45,15 @@ class FeatureGroupVersion(AbstractApiClass):
         self.cpu_size = cpuSize
         self.memory = memory
         self.use_original_csv_names = useOriginalCsvNames
+        self.python_function_bindings = pythonFunctionBindings
+        self.annotation_config = annotationConfig
         self.features = client._build_class(Feature, features)
         self.point_in_time_groups = client._build_class(
             PointInTimeGroup, pointInTimeGroups)
         self.code_source = client._build_class(CodeSource, codeSource)
 
     def __repr__(self):
-        return f"FeatureGroupVersion(feature_group_version={repr(self.feature_group_version)},\n  feature_group_id={repr(self.feature_group_id)},\n  sql={repr(self.sql)},\n  source_tables={repr(self.source_tables)},\n  created_at={repr(self.created_at)},\n  status={repr(self.status)},\n  error={repr(self.error)},\n  deployable={repr(self.deployable)},\n  cpu_size={repr(self.cpu_size)},\n  memory={repr(self.memory)},\n  use_original_csv_names={repr(self.use_original_csv_names)},\n  features={repr(self.features)},\n  point_in_time_groups={repr(self.point_in_time_groups)},\n  code_source={repr(self.code_source)})"
+        return f"FeatureGroupVersion(feature_group_version={repr(self.feature_group_version)},\n  feature_group_id={repr(self.feature_group_id)},\n  sql={repr(self.sql)},\n  source_tables={repr(self.source_tables)},\n  created_at={repr(self.created_at)},\n  status={repr(self.status)},\n  error={repr(self.error)},\n  deployable={repr(self.deployable)},\n  cpu_size={repr(self.cpu_size)},\n  memory={repr(self.memory)},\n  use_original_csv_names={repr(self.use_original_csv_names)},\n  python_function_bindings={repr(self.python_function_bindings)},\n  annotation_config={repr(self.annotation_config)},\n  features={repr(self.features)},\n  point_in_time_groups={repr(self.point_in_time_groups)},\n  code_source={repr(self.code_source)})"
 
     def to_dict(self):
         """
@@ -58,14 +62,14 @@ class FeatureGroupVersion(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'feature_group_version': self.feature_group_version, 'feature_group_id': self.feature_group_id, 'sql': self.sql, 'source_tables': self.source_tables, 'created_at': self.created_at, 'status': self.status, 'error': self.error, 'deployable': self.deployable, 'cpu_size': self.cpu_size, 'memory': self.memory, 'use_original_csv_names': self.use_original_csv_names, 'features': self._get_attribute_as_dict(self.features), 'point_in_time_groups': self._get_attribute_as_dict(self.point_in_time_groups), 'code_source': self._get_attribute_as_dict(self.code_source)}
+        return {'feature_group_version': self.feature_group_version, 'feature_group_id': self.feature_group_id, 'sql': self.sql, 'source_tables': self.source_tables, 'created_at': self.created_at, 'status': self.status, 'error': self.error, 'deployable': self.deployable, 'cpu_size': self.cpu_size, 'memory': self.memory, 'use_original_csv_names': self.use_original_csv_names, 'python_function_bindings': self.python_function_bindings, 'annotation_config': self.annotation_config, 'features': self._get_attribute_as_dict(self.features), 'point_in_time_groups': self._get_attribute_as_dict(self.point_in_time_groups), 'code_source': self._get_attribute_as_dict(self.code_source)}
 
     def create_snapshot_feature_group(self, table_name: str):
         """
-        Creates a Snapshot Feature Group corresponding to a specific feature group version.
+        Creates a Snapshot Feature Group corresponding to a specific Feature Group version.
 
         Args:
-            table_name (str): The name for the newly created Snapshot Feature Group table.
+            table_name (str): Name for the newly created Snapshot Feature Group table.
 
         Returns:
             FeatureGroup: Feature Group corresponding to the newly created Snapshot.
@@ -78,11 +82,11 @@ class FeatureGroupVersion(AbstractApiClass):
 
         Args:
             location (str): Cloud file location to export to.
-            export_file_format (str): File format to export to.
+            export_file_format (str): Enum string specifying the file format to export to.
             overwrite (bool): If true and a file exists at this location, this process will overwrite the file.
 
         Returns:
-            FeatureGroupExport: The FeatureGroupExport instance
+            FeatureGroupExport: The FeatureGroupExport instance.
         """
         return self.client.export_feature_group_version_to_file_connector(self.feature_group_version, location, export_file_format, overwrite)
 
@@ -91,15 +95,15 @@ class FeatureGroupVersion(AbstractApiClass):
         Export Feature group to Database Connector.
 
         Args:
-            database_connector_id (str): Database connector to export to.
-            object_name (str): The database object to write to
-            write_mode (str): Either INSERT or UPSERT
-            database_feature_mapping (dict): A key/value pair JSON Object of "database connector column" -> "feature name" pairs.
-            id_column (str): Required if mode is UPSERT. Indicates which database column should be used as the lookup key for UPSERT
-            additional_id_columns (list): For database connectors which support it, additional ID columns to use as a complex key for upserting
+            database_connector_id (str): Unique string identifier for the Database Connector to export to.
+            object_name (str): Name of the database object to write to.
+            write_mode (str): Enum string indicating whether to use INSERT or UPSERT.
+            database_feature_mapping (dict): Key/value pair JSON object of "database connector column" -> "feature name" pairs.
+            id_column (str): Required if write_mode is UPSERT. Indicates which database column should be used as the lookup key.
+            additional_id_columns (list): For database connectors which support it, additional ID columns to use as a complex key for upserting.
 
         Returns:
-            FeatureGroupExport: The FeatureGroupExport instance
+            FeatureGroupExport: The FeatureGroupExport instance.
         """
         return self.client.export_feature_group_version_to_database_connector(self.feature_group_version, database_connector_id, object_name, write_mode, database_feature_mapping, id_column, additional_id_columns)
 
@@ -111,20 +115,20 @@ class FeatureGroupVersion(AbstractApiClass):
             export_file_format (str): File format to export to.
 
         Returns:
-            FeatureGroupExport: The FeatureGroupExport instance
+            FeatureGroupExport: The FeatureGroupExport instance.
         """
         return self.client.export_feature_group_version_to_console(self.feature_group_version, export_file_format)
 
     def get_materialization_logs(self, stdout: bool = False, stderr: bool = False):
         """
-        Returns logs for materialized feature group version.
+        Returns logs for a materialized feature group version.
 
         Args:
-            stdout (bool):  Set True to get info logs
-            stderr (bool):  Set True to get error logs
+            stdout (bool): Set to True to get info logs.
+            stderr (bool): Set to True to get error logs.
 
         Returns:
-            FunctionLogs: A function logs.
+            FunctionLogs: A function logs object.
         """
         return self.client.get_materialization_logs(self.feature_group_version, stdout, stderr)
 
@@ -140,16 +144,29 @@ class FeatureGroupVersion(AbstractApiClass):
 
     def describe(self):
         """
-        Get a specific feature group version.
+        Describe a feature group version.
 
         Args:
-            feature_group_version (str): The unique ID associated with the feature group version.
+            feature_group_version (str): The unique identifier associated with the feature group version.
 
         Returns:
-            FeatureGroupVersion: A feature group version.
+            FeatureGroupVersion: The feature group version.
         """
         return self.client.describe_feature_group_version(self.feature_group_version)
 
+    def query_feature_group_explorer(self, message: str, chat_history: list = None):
+        """
+        Send a message to Abacus Chat for the specified feature group version and receive a response.
+
+        Args:
+            message (str): The message that you want to send to Abacus Chat.
+            chat_history (list): A list of chronologically ordered messages. Starts with a user message and alternates sources. Each message is represented as a dict with attributes: is_user (bool): Whether the message is from the user. timestamp (str): The timestamp of the message. text (list): Segmented parts of the message into text and code blocks.
+
+        Returns:
+            ChatBotResponse: An object representing the response from Abacus Chat, which includes an answer and updated chat history.
+        """
+        return self.client.query_feature_group_explorer(self.feature_group_version, message, chat_history)
+
     def wait_for_results(self, timeout=3600):
         """
         A waiting call until feature group version is materialized
@@ -208,14 +225,15 @@ class FeatureGroupVersion(AbstractApiClass):
         data_df = pd.DataFrame()
         with ThreadPoolExecutor(max_workers=max_workers) as executor:
             with tempfile.TemporaryDirectory() as tmp_dir:
+                df_parts = []
                 file_futures = [executor.submit(
                     self._download_avro_file, file_part, tmp_dir) for file_part in file_parts]
                 for future in file_futures:
                     part_path = future.result()
                     with open(part_path, 'rb') as part_data:
                         reader = fastavro.reader(part_data)
-                        data_df = pd.concat([data_df, pd.DataFrame(
-                            [r for r in reader])], ignore_index=True)
+                        df_parts.append(pd.DataFrame([r for r in reader]))
+                data_df = pd.concat(df_parts, ignore_index=True)
             for col in data_df.columns:
                 if pd.core.dtypes.common.is_datetime64_ns_dtype(data_df[col]):
                     data_df[col] = data_df[col].dt.tz_localize(None)
