@@ -12,17 +12,17 @@ class ModelMonitorVersion(AbstractApiClass):
             modelMonitorId (str): A reference to the model monitor this version belongs to.
             monitoringStartedAt (str): The start time and date of the monitoring process.
             monitoringCompletedAt (str): The end time and date of the monitoring process.
-            trainingFeatureGroupVersion (unique string identifiers): Feature group version IDs that this refresh pipeline run is monitoring.
-            predictionFeatureGroupVersion (unique string identifiers): Feature group version IDs that this refresh pipeline run is monitoring.
+            trainingFeatureGroupVersion (list[str]): Feature group version IDs that this refresh pipeline run is monitoring.
+            predictionFeatureGroupVersion (list[str]): Feature group version IDs that this refresh pipeline run is monitoring.
             error (str): Relevant error if the status is FAILED.
             pendingDeploymentIds (list): List of deployment IDs where deployment is pending.
             failedDeploymentIds (list): List of failed deployment IDs.
-            metricConfigs (json field): List of metric configs for the model monitor instance.
+            metricConfigs (list[dict]): List of metric configs for the model monitor instance.
             featureGroupMonitorConfigs (dict): Configurations for feature group monitor
-            metricTypes (dict): List of metric types.
-            modelVersion (unique string identifiers): Model version IDs that this refresh pipeline run is monitoring.
-            batchPredictionVersion (str): 
-            edaConfigs (list): 
+            metricTypes (list): List of metric types.
+            modelVersion (list[str]): Model version IDs that this refresh pipeline run is monitoring.
+            batchPredictionVersion (str): The batch prediction version this model monitor is monitoring
+            edaConfigs (list): The list of eda configs for the version
     """
 
     def __init__(self, client, modelMonitorVersion=None, status=None, modelMonitorId=None, monitoringStartedAt=None, monitoringCompletedAt=None, trainingFeatureGroupVersion=None, predictionFeatureGroupVersion=None, error=None, pendingDeploymentIds=None, failedDeploymentIds=None, metricConfigs=None, featureGroupMonitorConfigs=None, metricTypes=None, modelVersion=None, batchPredictionVersion=None, edaConfigs=None):
@@ -61,10 +61,10 @@ class ModelMonitorVersion(AbstractApiClass):
         Gets the label and prediction drifts for a model monitor.
 
         Args:
-            model_monitor_version (str): The unique identifier to a model monitor version created under the project.
+            model_monitor_version (str): Unique string identifier for a model monitor version created under the project.
 
         Returns:
-            DriftDistributions: An object describing training and prediction output label and prediction distributions.
+            DriftDistributions: Object describing training and prediction output label and prediction distributions.
         """
         return self.client.get_prediction_drift(self.model_monitor_version)
 
@@ -80,10 +80,10 @@ class ModelMonitorVersion(AbstractApiClass):
 
     def describe(self):
         """
-        Retrieves a full description of the specified model monitor version
+        Retrieves a full description of the specified model monitor version.
 
         Args:
-            model_monitor_version (str): The unique version ID of the model monitor version
+            model_monitor_version (str): The unique version ID of the model monitor version.
 
         Returns:
             ModelMonitorVersion: A model monitor version.
@@ -95,7 +95,7 @@ class ModelMonitorVersion(AbstractApiClass):
         Deletes the specified model monitor version.
 
         Args:
-            model_monitor_version (str): The ID of the model monitor version to delete.
+            model_monitor_version (str): Unique identifier of the model monitor version to delete.
         """
         return self.client.delete_model_monitor_version(self.model_monitor_version)
 
@@ -104,80 +104,23 @@ class ModelMonitorVersion(AbstractApiClass):
         Provides the data needed for decile metrics associated with the model monitor.
 
         Args:
-            metric_type (str): The metric type to get data for.
-            actual_values_to_detail (list): 
+            metric_type (str): The type of metric to get data for.
+            actual_values_to_detail (list): The actual values to detail.
 
         Returns:
             ModelMonitorVersionMetricData: Data associated with the metric.
         """
         return self.client.model_monitor_version_metric_data(self.model_monitor_version, metric_type, actual_values_to_detail)
 
-    def describe_eda_version(self):
-        """
-        Retrieves a full description of the specified model monitor version
-
-        Args:
-            model_monitor_version (str): The unique version ID of the model monitor version
-
-        Returns:
-            ModelMonitorVersion: A model monitor version.
-        """
-        return self.client.describe_eda_version(self.model_monitor_version)
-
-    def delete_eda_version(self):
-        """
-        Deletes the specified model monitor version.
-
-        Args:
-            model_monitor_version (str): The ID of the model monitor version to delete.
-        """
-        return self.client.delete_eda_version(self.model_monitor_version)
-
-    def get_eda_collinearity(self):
-        """
-        Gets the Collinearity between all features for the Exploratory Data Analysis.
-
-        Args:
-            model_monitor_version (str): The unique ID associated with the EDA instance.
-
-        Returns:
-            EdaCollinearity: An object with a record of correlations between each feature for an eda.
-        """
-        return self.client.get_eda_collinearity(self.model_monitor_version)
-
-    def get_eda_data_consistency(self, transformation_feature: str = None):
-        """
-        Gets the data consistency for the Exploratory Data Analysis.
-
-        Args:
-            transformation_feature (str): 
-
-        Returns:
-            EdaDataConsistency: An object with duplication, deletion and transformation data for Data Consistency Analysis for an eda.
-        """
-        return self.client.get_eda_data_consistency(self.model_monitor_version, transformation_feature)
-
-    def get_collinearity_for_feature(self, feature_name: str = None):
-        """
-        Gets the Collinearity for the given feature from the Exploratory Data Analysis.
-
-        Args:
-            feature_name (str): The name of the feature for which correlation shown
-
-        Returns:
-            EdaFeatureCollinearity: An object with a record of correlations for the provided feature for an eda.
-        """
-        return self.client.get_collinearity_for_feature(self.model_monitor_version, feature_name)
-
     def list_monitor_alert_versions_for_monitor_version(self):
         """
-        Retrieves the list of monitor alerts version for a specified monitor instance
+        Retrieves the list of monitor alert versions for a specified monitor instance.
 
         Args:
             model_monitor_version (str): The unique ID associated with the model monitor.
 
         Returns:
-            MonitorAlertVersion: An array of monitor alerts.
+            MonitorAlertVersion: A list of monitor alert versions.
         """
         return self.client.list_monitor_alert_versions_for_monitor_version(self.model_monitor_version)
 
@@ -186,31 +129,33 @@ class ModelMonitorVersion(AbstractApiClass):
         Returns monitoring logs for the model.
 
         Args:
-            stdout (bool):  Set True to get info logs
-            stderr (bool):  Set True to get error logs
+            stdout (bool): Set True to get info logs
+            stderr (bool): Set True to get error logs
 
         Returns:
             FunctionLogs: A function logs.
         """
         return self.client.get_model_monitoring_logs(self.model_monitor_version, stdout, stderr)
 
-    def get_drift_for_feature(self, feature_name: str):
+    def get_drift_for_feature(self, feature_name: str, nested_feature_name: str = None):
         """
         Gets the feature drift associated with a single feature in an output feature group from a prediction.
 
         Args:
             feature_name (str): Name of the feature to view the distribution of.
+            nested_feature_name (str): Optionally, the name of the nested feature that the feature is in.
         """
-        return self.client.get_drift_for_feature(self.model_monitor_version, feature_name)
+        return self.client.get_drift_for_feature(self.model_monitor_version, feature_name, nested_feature_name)
 
-    def get_outliers_for_feature(self, feature_name: str = None):
+    def get_outliers_for_feature(self, feature_name: str = None, nested_feature_name: str = None):
         """
         Gets a list of outliers measured by a single feature (or overall) in an output feature group from a prediction.
 
         Args:
             feature_name (str): Name of the feature to view the distribution of.
+            nested_feature_name (str): Optionally, the name of the nested feature that the feature is in.
         """
-        return self.client.get_outliers_for_feature(self.model_monitor_version, feature_name)
+        return self.client.get_outliers_for_feature(self.model_monitor_version, feature_name, nested_feature_name)
 
     def wait_for_monitor(self, timeout=1200):
         """
