@@ -7,11 +7,11 @@ class PredictionMetricVersion(AbstractApiClass):
 
         Args:
             client (ApiClient): An authenticated API Client instance
-            createdAt (str): Date and time when this preddiction metric version was created.
+            createdAt (str): Date and time when this prediction metric version was created.
             error (str): Relevant error if the status of this job version is FAILED.
             featureGroupVersion (str): The feature group version used as input to this prediction metric.
-            predictionMetricCompletedAt (str): The time and date computatations were completed for this job version.
-            predictionMetricConfig (json): Specification for prediction metric used to run this job.
+            predictionMetricCompletedAt (str): The time and date computations were completed for this job version.
+            predictionMetricConfig (dict): Specification for the prediction metric used to run this job.
             predictionMetricId (str): The unique identifier of the prediction metric this is a version of.
             predictionMetricStartedAt (str): The time and date computations were started for this job version.
             predictionMetricVersion (str): The unique identifier of this prediction metric version.
@@ -42,37 +42,6 @@ class PredictionMetricVersion(AbstractApiClass):
         """
         return {'created_at': self.created_at, 'error': self.error, 'feature_group_version': self.feature_group_version, 'prediction_metric_completed_at': self.prediction_metric_completed_at, 'prediction_metric_config': self.prediction_metric_config, 'prediction_metric_id': self.prediction_metric_id, 'prediction_metric_started_at': self.prediction_metric_started_at, 'prediction_metric_version': self.prediction_metric_version, 'status': self.status}
 
-    def refresh(self):
-        """
-        Calls describe and refreshes the current object's fields
-
-        Returns:
-            PredictionMetricVersion: The current object
-        """
-        self.__dict__.update(self.describe().__dict__)
-        return self
-
-    def describe(self):
-        """
-        Retrieves a full description of the specified prediction metric version
-
-        Args:
-            prediction_metric_version (str): The unique version ID of the prediction metric version
-
-        Returns:
-            PredictionMetricVersion: A prediction metric version. For more information, please refer to the details on the object (below).
-        """
-        return self.client.describe_prediction_metric_version(self.prediction_metric_version)
-
-    def delete(self):
-        """
-        Removes an existing prediction metric version.
-
-        Args:
-            prediction_metric_version (str): 
-        """
-        return self.client.delete_prediction_metric_version(self.prediction_metric_version)
-
     def wait_for_prediction_metric_version(self, timeout=1200):
         """
         A waiting call until the prediction metric version is ready.
