@@ -9,11 +9,11 @@ class Schema(AbstractApiClass):
             client (ApiClient): An authenticated API Client instance
             name (str): The unique name of the feature.
             featureMapping (str): The mapping of the feature. The possible values will be based on the project's use-case. See the (Use Case Documentation)[https://api.abacus.ai/app/help/useCases] for more details.
-            detectedFeatureMapping (str): 
+            detectedFeatureMapping (str): Detected feature mapping for this feature
             featureType (str): The underlying data type of each feature:  CATEGORICAL,  CATEGORICAL_LIST,  NUMERICAL,  TIMESTAMP,  TEXT,  EMAIL,  LABEL_LIST,  JSON,  OBJECT_REFERENCE,  MULTICATEGORICAL_LIST,  COORDINATE_LIST,  NUMERICAL_LIST,  TIMESTAMP_LIST.  Refer to the (guide on data types)[https://api.abacus.ai/app/help/class/FeatureType] for more information.
-            detectedFeatureType (str): 
-            dataType (str): The underlying data type of each feature:  INTEGER,  FLOAT,  STRING,  DATE,  DATETIME,  BOOLEAN,  LIST,  STRUCT.  Refer to the (guide on data types)[https://api.abacus.ai/app/help/class/DataType] for more information.
-            detectedDataType (str): 
+            detectedFeatureType (str): The detected feature type for this feature
+            dataType (str): The underlying data type of each feature:  INTEGER,  FLOAT,  STRING,  DATE,  DATETIME,  BOOLEAN,  LIST,  STRUCT,  NULL.  Refer to the (guide on data types)[https://api.abacus.ai/app/help/class/DataType] for more information.
+            detectedDataType (str): The detected data type for this feature
     """
 
     def __init__(self, client, name=None, featureMapping=None, detectedFeatureMapping=None, featureType=None, detectedFeatureType=None, dataType=None, detectedDataType=None):
